==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/text/l10n/oc.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "document tèxt",
    "Readme" : "Readme",
    "Text" : "Tèxt",
    "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
    "Use current version" : "Utilizar la version actuala",
    "Use the saved version" : "Utilizar la version salvada",
    "Reconnect" : "Se reconnectar",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
    "Edit guest name" : "Modificar lo nom de convidat",
    "Guest" : "Convidat",
    "Save guest name" : "Enregistrar lo nom de convidat",
    "guest" : "convidat",
    "Show author colors" : "Afichar las colors dels utilizaires",
    "Saving …" : "Enregistrament...",
    "Saved" : "Enregistrat",
    "Last saved {lastSaved}" : "Darrièr enregistrament {lastSaved}",
    "Unsaved changes" : "Modificacions pas enregistradas",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Bold" : "Gras",
    "Italic" : "Italica",
    "Heading 1" : "Títol 1",
    "Heading 6" : "Títol 6",
    "Unordered list" : "Lista pas ordenada",
    "Ordered list" : "Lista ordenada",
    "Blockquote" : "Citacion",
    "Code block" : "Còdi",
    "Add notes, lists or links …" : "Apondre nòtas, listas o ligamas…",
    "Undo" : "Anullar",
    "Redo" : "Refar",
    "Headings" : "Títols",
    "Heading 2" : "Títol 2",
    "Heading 3" : "Títol 3",
    "Heading 4" : "Títol 4",
    "Heading 5" : "Títol 5",
    "Info" : "Info",
    "Success" : "Succès",
    "Warning" : "Avertiment",
    "Insert emoji" : "Inserir emoji",
    "Command" : "Comanda",
    "Edit" : "Modificar",
    "New text document" : "Novèl fichièr tèxte",
    "Enter your name so other users can see who is editing" : "Picatz vòstre nom per que los autres utilizaires vejan qual es a modificar",
    "Insert image" : "Inserir imatge",
    "Insert an image" : "Inserir un imatge",
    "Link file" : "Ligam fichièr",
    "Currently active users:" : "Utilizaires actius :",
    "ToDo list" : "Lista a far",
    "Emoji picker" : "Selector emoji",
    "Remove Link" : "Suprimir ligam"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-26.0.0.tar.bz2: nextcloud/apps/text/l10n/oc.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "document tèxt",
    "Readme" : "Readme",
    "Text" : "Tèxt",
    "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
    "Use current version" : "Utilizar la version actuala",
    "Use the saved version" : "Utilizar la version salvada",
    "Reconnect" : "Se reconnectar",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
    "Edit guest name" : "Modificar lo nom de convidat",
    "Guest" : "Convidat",
    "Save guest name" : "Enregistrar lo nom de convidat",
    "guest" : "convidat",
    "Show author colors" : "Afichar las colors dels utilizaires",
    "Offline" : "Fòra linha",
    "Saving …" : "Enregistrament...",
    "Saved" : "Enregistrat",
    "Unsaved changes" : "Modificacions pas enregistradas",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Bold" : "Gras",
    "Italic" : "Italica",
    "Heading 1" : "Títol 1",
    "Heading 6" : "Títol 6",
    "Unordered list" : "Lista pas ordenada",
    "Ordered list" : "Lista ordenada",
    "Blockquote" : "Citacion",
    "Code block" : "Còdi",
    "Translate" : "Translate",
    "Undo" : "Anullar",
    "Redo" : "Refar",
    "Headings" : "Títols",
    "Heading 2" : "Títol 2",
    "Heading 3" : "Títol 3",
    "Heading 4" : "Títol 4",
    "Heading 5" : "Títol 5",
    "Info" : "Info",
    "Success" : "Succès",
    "Warning" : "Avertiment",
    "Insert emoji" : "Inserir emoji",
    "Command" : "Comanda",
    "Add notes, lists or links …" : "Apondre nòtas, listas o ligamas…",
    "Edit" : "Modificar",
    "Last saved {lastSaved}" : "Darrièr enregistrament {lastSaved}",
    "Enter your name so other users can see who is editing" : "Picatz vòstre nom per que los autres utilizaires vejan qual es a modificar",
    "Insert an image" : "Inserir un imatge",
    "Link file" : "Ligam fichièr",
    "Remove Link" : "Suprimir ligam",
    "ToDo list" : "Lista a far",
    "Emoji picker" : "Selector emoji",
    "Insert image" : "Inserir imatge"
},
"nplurals=2; plural=(n > 1);");
